searchData={"content_type":"text/markdown","items":[{"doc":"Bump version number in mix.exs and create a new git tag.","ref":"Mix.Tasks.Bump.html","title":"mix bump","type":"task"},{"doc":"Runs the task with the given arguments.","ref":"Mix.Tasks.Bump.html#run/1","title":"Mix.Tasks.Bump.run/1","type":"function"},{"doc":"An Elixir wrapper around the LaunchDarkly Erlang client\n\nTo start the client, call `Zexbox.Flags.start/2` when starting your application\nwith a map of config options and an optional tag:\n\n```elixir\ndef start(_type, _args) do\n  Zexbox.Flags.start()\n  ...\nend\n```\n\nTo make sure that the client shuts down, you should call Zexbox.Flags.stop/1\nwhen your application shuts down:\n\n```elixir\ndef stop(_type, _args) do\n  Zexbox.Flags.stop()\n  ...\nend\n```","ref":"Zexbox.Flags.html","title":"Zexbox.Flags","type":"module"},{"doc":"Starts the LaunchDarkly client using the `:flags` application config and the `:default` tag.","ref":"Zexbox.Flags.html#start/0","title":"Zexbox.Flags.start/0","type":"function"},{"doc":"iex> Zexbox.Flags.start()\n    :ok\n    iex> Zexbox.Flags.start()\n    {:error, :already_started, #PID<0.602.0>}","ref":"Zexbox.Flags.html#start/0-examples","title":"Examples - Zexbox.Flags.start/0","type":"function"},{"doc":"Starts the LaunchDarkly client with the given config or the given tag.","ref":"Zexbox.Flags.html#start/1","title":"Zexbox.Flags.start/1","type":"function"},{"doc":"iex> Zexbox.Flags.start(%{sdk_key: \"my-sdk-key\"})\n    :ok\n    iex> Zexbox.Flags.start(%{sdk_key: \"my-sdk-key\"})\n    {:error, :already_started, #PID<0.602.0>}\n    iex>","ref":"Zexbox.Flags.html#start/1-examples","title":"Examples - Zexbox.Flags.start/1","type":"function"},{"doc":"Starts the LaunchDarkly client with the given config and tag.","ref":"Zexbox.Flags.html#start/2","title":"Zexbox.Flags.start/2","type":"function"},{"doc":"iex> Zexbox.Flags.start(%{sdk_key: \"my-sdk-key\"}, :my_tag)\n    :ok\n\n    iex> Zexbox.Flags.start(%{sdk_key: \"my-sdk-key\"}, :my_tag)\n    {:error, :already_started, #PID<0.602.0>}","ref":"Zexbox.Flags.html#start/2-examples","title":"Examples - Zexbox.Flags.start/2","type":"function"},{"doc":"Stops the ldclient with the default tag.","ref":"Zexbox.Flags.html#stop/0","title":"Zexbox.Flags.stop/0","type":"function"},{"doc":"Stops the ldclient with the given tag.","ref":"Zexbox.Flags.html#stop/1","title":"Zexbox.Flags.stop/1","type":"function"},{"doc":"Gets the variation of a flag for the given key, context, and default tag.","ref":"Zexbox.Flags.html#variation/3","title":"Zexbox.Flags.variation/3","type":"function"},{"doc":"iex> Zexbox.Flags.variation(\"my-flag\", %{key: \"user-key\"}, false)\n    true\n\n    iex> Zexbox.Flags.variation(\"my-flag\", %{key: \"user-key\"}, false)\n    {:error, {:not_found, \"my-flag\"}}","ref":"Zexbox.Flags.html#variation/3-examples","title":"Examples - Zexbox.Flags.variation/3","type":"function"},{"doc":"Gets the variation of a flag for the given key, context, default value, and tag.","ref":"Zexbox.Flags.html#variation/4","title":"Zexbox.Flags.variation/4","type":"function"},{"doc":"iex> Zexbox.Flags.variation(\"my-flag\", %{key: \"user-key\"}, false, :my_tag)\n    true\n\n    iex> Zexbox.Flags.variation(\"my-flag\", %{key: \"user-key\"}, false, :my_tag)\n    {:error, {:not_found, \"my-flag\"}}","ref":"Zexbox.Flags.html#variation/4-examples","title":"Examples - Zexbox.Flags.variation/4","type":"function"},{"doc":"Module for logging events in Zexbox.","ref":"Zexbox.Logging.html","title":"Zexbox.Logging","type":"module"},{"doc":"Attaches Telemetry handlers for Phoenix controller events.\n\nThis function sets up handlers for the `[:phoenix, :endpoint, :stop]` and `[:phoenix, :endpoint, :start]` events.\nThe handlers are named `\"phoenix_controller_logs_stop\"` and `\"phoenix_controller_logs_start\"`,\nboth of which use the `LogHandler.handle_event/4` function to process the events.","ref":"Zexbox.Logging.html#attach_controller_logs!/0","title":"Zexbox.Logging.attach_controller_logs!/0","type":"function"},{"doc":"iex> Logging.attach_controller_logs()\n    :ok\n    iex> Logging.attach_controller_logs()\n    ** (RuntimeError) event already exists","ref":"Zexbox.Logging.html#attach_controller_logs!/0-examples","title":"Examples - Zexbox.Logging.attach_controller_logs!/0","type":"function"},{"doc":"Handles the default start and stop events for phoenix endpoints. This makes use of the\ndefault [Logger](https://hexdocs.pm/logger/main/Logger.html) module and as such will obey the :logger configuration\nspecified in your app.","ref":"Zexbox.Logging.LogHandler.html","title":"Zexbox.Logging.LogHandler","type":"module"},{"doc":"This function is called by the Phoenix endpoint when a controller action is started or finished.","ref":"Zexbox.Logging.LogHandler.html#handle_event/4","title":"Zexbox.Logging.LogHandler.handle_event/4","type":"function"},{"doc":"iex> Zexbox.Logging.LogHandler.handle_event([:phoenix, :endpoint, :stop], measurements, metadata, config)\n    :ok","ref":"Zexbox.Logging.LogHandler.html#handle_event/4-examples","title":"Examples - Zexbox.Logging.LogHandler.handle_event/4","type":"function"},{"doc":"This module is esponsible for setting up and supervising the metrics collection and telemetry.\nIt attaches telemetry handlers for capturing metrics related to your Phoenix endpoints.\n\n```elixir\ndef start(_type, args) do\n  children = [{Zexbox.Metrics, []}]\n  Supervisor.start_link(children, opts)\nend\n```","ref":"Zexbox.Metrics.html","title":"Zexbox.Metrics","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Zexbox.Metrics.html#child_spec/1","title":"Zexbox.Metrics.child_spec/1","type":"function"},{"doc":"Initializes the supervisor with the required child processes.","ref":"Zexbox.Metrics.html#init/1","title":"Zexbox.Metrics.init/1","type":"function"},{"doc":"iex> Zexbox.Metrics.init(nil)\n    {:ok,\n     {%{intensity: 3, period: 5, strategy: :one_for_one, auto_shutdown: :never},\n      [\n        %{\n          id: Zexbox.Metrics.Connection,\n          start: {Instream.Connection.Supervisor, :start_link, [Zexbox.Metrics.Connection]}\n        }\n      ]}}","ref":"Zexbox.Metrics.html#init/1-examples","title":"Examples - Zexbox.Metrics.init/1","type":"function"},{"doc":"Starts the metrics supervisor and attaches the controller metrics.","ref":"Zexbox.Metrics.html#start_link/1","title":"Zexbox.Metrics.start_link/1","type":"function"},{"doc":"iex> Zexbox.Metrics.start_link(nil)\n      {:ok, #PID<0.123.0>}","ref":"Zexbox.Metrics.html#start_link/1-examples","title":"Examples - Zexbox.Metrics.start_link/1","type":"function"},{"doc":"A client module for writing metrics to InfluxDB.","ref":"Zexbox.Metrics.Client.html","title":"Zexbox.Metrics.Client","type":"module"},{"doc":"This module provides functions to write metrics to InfluxDB, a time-series database that allows for efficient storage and querying of data with a timestamp.\n\nTo use this module, you need to have the `Zexbox.Metrics.Connection` application running. Make sure to start it as an application in your supervision tree:\n\n```elixir\ndef start(_type, _args) do\n  children = [\n    {Zexbox.Metrics.Connection, []}\n  ]\n  Supervisor.start_link(children, strategy: :one_for_one)\nend\n```","ref":"Zexbox.Metrics.Client.html#module-overview","title":"Overview - Zexbox.Metrics.Client","type":"module"},{"doc":"The main function provided by this module is write_metric/1. It accepts a metric data structure and writes it to InfluxDB.","ref":"Zexbox.Metrics.Client.html#module-writing-metrics","title":"Writing Metrics - Zexbox.Metrics.Client","type":"module"},{"doc":"","ref":"Zexbox.Metrics.Client.html#module-examples","title":"Examples - Zexbox.Metrics.Client","type":"module"},{"doc":"```elixir\niex> metric = %Zexbox.Metrics.Series.Generic{\n...>   measurement: \"my_measurement\",\n...>   fields: %{\n...>     \"my_field\" => 1\n...>   },\n...>   tags: %{\n...>     \"my_tag\" => \"my_value\"\n...>   }\n...> }\niex> Zexbox.Metrics.Client.write_metric(metric)\n{:ok, %Zexbox.Metrics.Series.Generic{\n  measurement: \"my_measurement\",\n  fields: %{\n    \"my_field\" => 1\n  },\n  tags: %{\n    \"my_tag\" => \"my_value\"\n  }\n}}\n```","ref":"Zexbox.Metrics.Client.html#module-writing-custom-metrics","title":"Writing Custom metrics - Zexbox.Metrics.Client","type":"module"},{"doc":"If there is an error while writing the metric, the function will log the error using the Logger module without crashing the process,","ref":"Zexbox.Metrics.Client.html#module-error-handling","title":"Error Handling - Zexbox.Metrics.Client","type":"module"},{"doc":"Write a metric to InfluxDB.","ref":"Zexbox.Metrics.Client.html#write_metric/1","title":"Zexbox.Metrics.Client.write_metric/1","type":"function"},{"doc":"iex> Zexbox.Metrics.Client.write_metric(%ControllerSeries{})\n    {:ok, %ControllerSeries{}}","ref":"Zexbox.Metrics.Client.html#write_metric/1-examples","title":"Examples - Zexbox.Metrics.Client.write_metric/1","type":"function"},{"doc":"","ref":"Zexbox.Metrics.Client.html#t:series/0","title":"Zexbox.Metrics.Client.series/0","type":"type"},{"doc":"Connection for writing metrics to InfluxDB.","ref":"Zexbox.Metrics.Connection.html","title":"Zexbox.Metrics.Connection","type":"module"},{"doc":"This module defines generic controller metrics.\n\nThe fields captured are:\n\n* duration_ms - The time taken to process the request in milliseconds\n* success - Whether the request was successful (1.0) or not (0.0)\n* path - The path of the request\n* http_referer - The referer of the request\n* count - The number of requests\n* request_id - The request ID of the request\n\nThe tags allowed are:\n\n* controller - The name of the controller\n* action - The name of the action\n* method - The HTTP method of the request\n* format - The format of the request\n* status - The status of the request","ref":"Zexbox.Metrics.ControllerSeries.html","title":"Zexbox.Metrics.ControllerSeries","type":"module"},{"doc":"Adds a field to the series","ref":"Zexbox.Metrics.ControllerSeries.html#field/3","title":"Zexbox.Metrics.ControllerSeries.field/3","type":"function"},{"doc":"Adds a tag to the series","ref":"Zexbox.Metrics.ControllerSeries.html#tag/3","title":"Zexbox.Metrics.ControllerSeries.tag/3","type":"function"},{"doc":"","ref":"Zexbox.Metrics.ControllerSeries.html#t:t/0","title":"Zexbox.Metrics.ControllerSeries.t/0","type":"type"},{"doc":"This module is responsible for logging controller metrics to influx","ref":"Zexbox.Metrics.MetricHandler.html","title":"Zexbox.Metrics.MetricHandler","type":"module"},{"doc":"This function is called by the Phoenix endpoint when a controller action is\nfinished. It will log the controller metrics to influx.","ref":"Zexbox.Metrics.MetricHandler.html#handle_event/4","title":"Zexbox.Metrics.MetricHandler.handle_event/4","type":"function"},{"doc":"iex> Zexbox.Metrics.MetricHandler.handle_event([:phoenix, :endpoint, :stop], measurements, metadata, config)\n    :ok","ref":"Zexbox.Metrics.MetricHandler.html#handle_event/4-examples","title":"Examples - Zexbox.Metrics.MetricHandler.handle_event/4","type":"function"},{"doc":"This module defines a simple struct to write metrics to InfluxDB.\n\nthe attributes are:\n* measurement - The name of the measurement\n* fields - The fields of the measurement, these are the values you want to aggregate on\n* tags - The tags of the measurement, these are usually identifiers for the values but you can't aggregate on them\n* timestamp - The timestamp of the measurement, it is optional, if it's missing in the struct, InfluxDB will use the current time","ref":"Zexbox.Metrics.Series.html","title":"Zexbox.Metrics.Series","type":"module"},{"doc":"Adds a field to the series","ref":"Zexbox.Metrics.Series.html#field/3","title":"Zexbox.Metrics.Series.field/3","type":"function"},{"doc":"iex> Series.field(%Series{measurement: \"my_measurement\"}, :field1, 42)\n    %Series{\n      measurement: \"my_measurement\",\n      fields: %{field1: 42},\n      tags: %{},\n      timestamp: ~U[2021-09-29 12:00:00Z]\n    }","ref":"Zexbox.Metrics.Series.html#field/3-examples","title":"Examples - Zexbox.Metrics.Series.field/3","type":"function"},{"doc":"Creates a new struct with the given measurement and the current time as the timestamp","ref":"Zexbox.Metrics.Series.html#new/1","title":"Zexbox.Metrics.Series.new/1","type":"function"},{"doc":"iex> Series.new(\"my_measurement\")\n    %Series{\n      measurement: \"my_measurement\",\n      fields: %{},\n      tags: %{},\n      timestamp: ~U[2021-09-29 12:00:00Z]\n    }","ref":"Zexbox.Metrics.Series.html#new/1-examples","title":"Examples - Zexbox.Metrics.Series.new/1","type":"function"},{"doc":"Adds a tag to the series","ref":"Zexbox.Metrics.Series.html#tag/3","title":"Zexbox.Metrics.Series.tag/3","type":"function"},{"doc":"iex> Series.tag(%Series{measurement: \"my_measurement\"}, :tag1, \"tag_value\")\n    %Series{\n      measurement: \"my_measurement\",\n      fields: %{},\n      tags: %{tag1: \"tag_value\"},\n      timestamp: ~U[2021-09-29 12:00:00Z]\n    }","ref":"Zexbox.Metrics.Series.html#tag/3-examples","title":"Examples - Zexbox.Metrics.Series.tag/3","type":"function"},{"doc":"","ref":"Zexbox.Metrics.Series.html#t:t/0","title":"Zexbox.Metrics.Series.t/0","type":"type"},{"doc":"A (very) thin wrapper around the :telemetry erlang module","ref":"Zexbox.Telemetry.html","title":"Zexbox.Telemetry","type":"module"},{"doc":"Attaches the given handler to the specified event.\n\nsee :telemetry.attach/4 for more information","ref":"Zexbox.Telemetry.html#attach/4","title":"Zexbox.Telemetry.attach/4","type":"function"},{"doc":"iex> Zexbox.Telemetry.attach(:my_event, [:my, :event], &MyAppHandler.my_handler/3, nil)\n    :ok","ref":"Zexbox.Telemetry.html#attach/4-examples","title":"Examples - Zexbox.Telemetry.attach/4","type":"function"},{"doc":"","ref":"Zexbox.Telemetry.html#t:callback/0","title":"Zexbox.Telemetry.callback/0","type":"type"},{"doc":"","ref":"Zexbox.Telemetry.html#t:config/0","title":"Zexbox.Telemetry.config/0","type":"type"},{"doc":"","ref":"Zexbox.Telemetry.html#t:event_name/0","title":"Zexbox.Telemetry.event_name/0","type":"type"},{"doc":"","ref":"Zexbox.Telemetry.html#t:event_params/0","title":"Zexbox.Telemetry.event_params/0","type":"type"}],"producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}